# Permission to Relicense under MPLv2 or any other OSI approved license chosen by the current PyZMQ BDFL

This is a statement by Boris Feld that grants permission to relicense its
copyrights in the Python ZeroMQ bindings (pyzmq) under the Mozilla Public
License v2 (MPLv2) or any other Open Source Initiative approved license chosen
by the current PyZMQ BDFL (Benevolent Dictator for Life).

A portion of the commits made by the GitHub handle "Lothiraldan", with commit
author "FELD Boris <lothiraldan@gmail.com>", are copyright of Boris Feld. This
document hereby grants the pyzmq project team permission to relicense pyzmq,
including all past, present, and future contributions of the author listed
above.

Boris Feld 2017/07/18
